@@ -75,14 +75,6 @@ public class BasicFeature extends AbstractFeature {
         this.thickEnd = feature.thickEnd;
     }
 
-    /**
-     * Method description
-     *
-     * @return
-     */
-    public BasicFeature copy() {
-        return new BasicFeature(this);
-    }
 
     /**
      * @param identifier
@@ -120,35 +112,26 @@ public class BasicFeature extends AbstractFeature {
 
         String name = getName();
         if (name != null) {
-            valueString.append("<b>" + name + "</b>");
+            valueString.append("<b>" + name + "</b><br>");
+        }
+        valueString.append(getLocusString());
+        if (type != null) {
+            valueString.append("<br>Type = " + type);
         }
         if ((identifier != null) && ((name == null) || !name.equals(identifier))) {
-            valueString.append("<br>" + identifier);
+            valueString.append("<br>id = " + identifier);
         }
 
-
         if (!Float.isNaN(score)) {
             valueString.append("<br>Score = " + score);
         }
         if (description != null) {
             valueString.append("<br>" + description);
         }
-        if (type != null) {
-            valueString.append(type);
-            valueString.append("<br>");
-        }
         if (attributes != null) {
             valueString.append(getAttributeString());
         }
 
-        valueString.append("<br>" + getLocusString());
-
-
-        // Display attributes, if any
-        if (attributes != null && attributes.size() > 0) {
-
-        }
-
 
         // Get exon number, if over an exon
         int posZero = (int) position;
@@ -209,6 +192,56 @@ public class BasicFeature extends AbstractFeature {
         exons.add(region);
     }
 
+    /**
+     * Add a UTR or CDS feature from a GFF or EMBL/NCBI type format.  If the feature overlaps an existing exon merge
+     * the two, otherwise create a new one.
+     *
+     * @param bf
+     */
+    public void addUTRorCDS(BasicFeature bf) {
+        boolean found = false;
+        if (exons == null) {
+            exons = new ArrayList();
+        }
+
+        final String exonType = bf.getType();
+        for (Exon exon : exons) {
+            if (exon.contains(bf)) {
+                // Replace exon attributes with coding features.  Perhaps in the future we will merge them.
+                exon.setAttributes(bf.getAttributes());
+                if (SequenceOntology.cdsTypes.contains(exonType)) {
+                    exon.setNonCoding(false);
+                    exon.setCodingStart(bf.getStart());
+                    exon.setCodingEnd(bf.getEnd());
+
+                } else if (SequenceOntology.utrTypes.contains(exonType)) {
+                    exon.setNonCoding(true);
+                    boolean rhs =
+                            (SequenceOntology.fivePrimeUTRTypes.contains(exonType) && bf.getStrand() == Strand.POSITIVE) ||
+                                    (SequenceOntology.threePrimeUTRTypes.contains(exonType) && bf.getStrand() == Strand.NEGATIVE);
+                    if (rhs) {
+                        exon.setCodingStart(bf.getEnd());
+                        exon.setCodingEnd(bf.getEnd());
+                    } else {
+                        exon.setCodingEnd(bf.getStart());
+                        exon.setCodingStart(bf.getStart());
+                    }
+                }
+
+                found = true;
+                break;
+            }
+        }
+
+        if (!found) {
+            // No match
+            final Exon exon = new Exon(bf);
+            exon.setNonCoding(!SequenceOntology.cdsTypes.contains(bf.getType()));
+            addExon(exon);
+        }
+
+    }
+
 
     @Override
     public String getIdentifier() {
