@@ -12,10 +12,11 @@ package org.broad.igv.sam;
 
 //~--- non-JDK imports --------------------------------------------------------
 
-import net.sf.samtools.*;
+import net.sf.samtools.SAMFileHeader;
+import net.sf.samtools.SAMReadGroupRecord;
+import net.sf.samtools.SAMRecord;
 import org.apache.log4j.Logger;
 import org.broad.igv.PreferenceManager;
-import org.broad.igv.annotations.ForTesting;
 import org.broad.igv.feature.Strand;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.genome.GenomeManager;
@@ -23,9 +24,6 @@ import org.broad.igv.track.WindowFunction;
 import org.broad.igv.ui.color.ColorUtilities;
 
 import java.awt.*;
-import java.lang.ref.Reference;
-import java.lang.ref.SoftReference;
-import java.lang.ref.WeakReference;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
@@ -55,31 +53,12 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
     private int end;    // ditto
     private int alignmentStart;
     private int alignmentEnd;
-    private int readLength;
-    private boolean readNegativeStrandFlag;
-    private boolean duplicateReadFlag;
-    private boolean readUnmappedFlag;
-    private boolean readPairedFlag;
-    private boolean properPairFlag;
 
     /**
-     * DO NOT ACCESS THIS FIELD DIRECTLY, EVEN WITHIN THIS CLASS.
-     * USE {@link #getRecord}.
+     * Picard object upon which this SamAlignment is based
      */
     private SAMRecord record;
-    private Reference<SAMRecord> softRecord;
 
-    /**
-     * DO NOT ACCESS THIS FIELD DIRECTLY, EVEN WITHIN THIS CLASS
-     * USE {@link #getReadSequence}
-     */
-    private String readSequence;
-    private Reference<String> softReadSequence;
-
-
-    private String cigarString;
-    private boolean firstRead = false;
-    private boolean secondRead = false;
     private String mateSequence = null;
     private String pairOrientation = "";
     private Color defaultColor = AlignmentRenderer.grey1;
@@ -87,18 +66,9 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
     private String library;
     private String sample;
 
-    /**
-     * Pointer to the reader and location in the file
-     * where this file was derived from
-     */
-    private SAMFileSource fileSource;
-
-    private boolean firstInPair;
     private Strand firstOfPairStrand;
     private Strand secondOfPairStrand;
 
-    private String flowOrder;
-
     /**
      * Converts a DNA integer value to its reverse compliment integer value.
      */
@@ -123,19 +93,10 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
 
     public static final String REDUCE_READS_TAG = "RR";
 
-    /**
-     * Whether to load read sequence / record / other data lazily.
-     * Eventually we will likely remove this flag, here for easy testing
-     */
-    public static final boolean DEFAULT_LAZY_LOAD = Boolean.parseBoolean(System.getProperty("DEFAULT_LAZY_LOAD", "false"));
-
     public SamAlignment(SAMRecord record) {
-        flowOrder = null;
         String keySequence = null;
 
         this.record = record;
-        this.softRecord = new WeakReference<SAMRecord>(record);
-        this.fileSource = record.getFileSource();
 
         String refName = record.getReferenceName();
         Genome genome = GenomeManager.getInstance().getCurrentGenome();
@@ -146,32 +107,21 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
         this.start = this.alignmentStart;   // might be modified later for soft clipping
         this.alignmentEnd = Math.max(alignmentStart, record.getAlignmentEnd());
         this.end = alignmentEnd;   // might be modified later for soft clipping
-        this.cigarString = record.getCigarString();
         this.setMappingQuality(record.getMappingQuality());
         this.readName = record.getReadName().trim();
-        this.readNegativeStrandFlag = record.getReadNegativeStrandFlag();
-        this.duplicateReadFlag = record.getDuplicateReadFlag();
-        this.readUnmappedFlag = record.getReadUnmappedFlag();
-        this.readPairedFlag = record.getReadPairedFlag();
         this.setInferredInsertSize(record.getInferredInsertSize());
 
-        this.readSequence = record.getReadString();
-        this.softReadSequence = new SoftReference<String>(record.getReadString());
-
-        this.readLength = record.getReadLength();
-        this.firstInPair = record.getReadPairedFlag() ? record.getFirstOfPairFlag() : true;
-
         setMatePair(genome);
         setPairOrientation();
         setPairStrands();
 
         SAMFileHeader header = record.getHeader();
+        String flowOrder = null;
         if (header != null) {
             readGroup = (String) record.getAttribute("RG");
             if (readGroup != null) {
                 SAMReadGroupRecord rgRec = header.getReadGroup(readGroup);
                 if (rgRec != null) {
-                    String platform = rgRec.getPlatform();
                     this.sample = rgRec.getSample();
                     this.library = rgRec.getLibrary();
                     flowOrder = rgRec.getFlowOrder();
@@ -194,22 +144,15 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
         }
     }      // End constructor
 
-    public String getFlowOrder() {
-        return flowOrder;
-    }
-
     private void setMatePair(Genome genome) {
         SAMRecord record = getRecord();
         if (record.getReadPairedFlag()) {
             String mateReferenceName = record.getMateReferenceName();
             String mateChr = genome == null ? mateReferenceName : genome.getChromosomeAlias(mateReferenceName);
-            this.properPairFlag = record.getProperPairFlag();
             this.setMate(new ReadMate(mateChr,
                     record.getMateAlignmentStart(),
                     record.getMateNegativeStrandFlag(),
                     record.getMateUnmappedFlag()));
-            this.firstRead = record.getFirstOfPairFlag();
-            this.secondRead = record.getSecondOfPairFlag();
         }
 
     }
@@ -217,7 +160,7 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
     private void setPairOrientation() {
         SAMRecord record = getRecord();
         if (record.getReadPairedFlag() &&
-                !readUnmappedFlag &&
+                !record.getReadUnmappedFlag() &&
                 !record.getMateUnmappedFlag() &&
                 record.getReferenceName().equals(record.getMateReferenceName())) {
 
@@ -338,7 +281,7 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
 
         if (cigarString.equals("*")) {
             alignmentBlocks = new AlignmentBlock[1];
-            alignmentBlocks[0] = new AlignmentBlock(getStart(), readBases, readBaseQualities, this);
+            alignmentBlocks[0] = new AlignmentBlock(getChr(), getStart(), readBases, readBaseQualities);
             return;
         }
 
@@ -369,7 +312,11 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
                 } else if (op == INSERTION) {
                     nInsertions++;
                     nGaps++; // "virtual" gap, account for artificial block split @ insertion
+                } else if (op == PADDING) {
+                    nGaps++;
                 }
+
+
                 if (firstOperator && op == SOFT_CLIP) {
                     softClippedBaseCount += nBases;
                 }
@@ -402,7 +349,7 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
         FlowSignalContextBuilder fBlockBuilder = null;
         if (null != flowSignals) {
             if (0 < readBases.length) {
-                fBlockBuilder = new FlowSignalContextBuilder(flowSignals, flowOrder, flowOrderStart, readBases, fromIdx, this.readNegativeStrandFlag);
+                fBlockBuilder = new FlowSignalContextBuilder(flowSignals, flowOrder, flowOrderStart, readBases, fromIdx, this.isNegativeStrand());
             }
         }
         prevOp = 0;
@@ -414,49 +361,12 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
                 }
                 if (operatorIsMatch(showSoftClipped, op.operator)) {
 
-                    byte[] blockBases = new byte[op.nBases];
-                    byte[] blockQualities = new byte[op.nBases];
-                    short[] blockCounts = new short[op.nBases];
-                    AlignmentBlock block = null;
-
-                    //Default value
-                    Arrays.fill(blockQualities, (byte) 126);
-
-                    int nBasesAvailable = readBases.length - fromIdx;
-
-                    // TODO -- represent missing sequence ("*") explicitly for efficiency.
-                    if (readBases == null || readBases.length == 0) {
-                        Arrays.fill(blockBases, (byte) '=');
-                    } else if (nBasesAvailable < op.nBases) {
-                        Arrays.fill(blockBases, (byte) '?');
-                    } else {
-                        System.arraycopy(readBases, fromIdx, blockBases, 0, op.nBases);
-                    }
-
-                    nBasesAvailable = readBaseQualities.length - fromIdx;
-                    if (readBaseQualities == null || readBaseQualities.length == 0 || nBasesAvailable < op.nBases) {
-                        Arrays.fill(blockQualities, (byte) 126);
-                    } else {
-                        System.arraycopy(readBaseQualities, fromIdx, blockQualities, 0, op.nBases);
-                    }
-
-                    if (readRepresentativeCounts != null) {
-                        System.arraycopy(readRepresentativeCounts, fromIdx, blockCounts, 0, op.nBases);
-                    }
-
-                    if (null != fBlockBuilder) {
-                        block = AlignmentBlock.getInstance(blockStart, blockBases, blockQualities,
-                                fBlockBuilder.getFlowSignalContext(readBases, fromIdx, op.nBases), this);
-                    } else {
-                        block = AlignmentBlock.getInstance(blockStart, blockBases, blockQualities, this);
-                    }
+                    AlignmentBlock block = buildAlignmentBlock(fBlockBuilder, readBases, readBaseQualities,
+                            readRepresentativeCounts, getChr(), blockStart, fromIdx, op.nBases, true);
 
                     if (op.operator == SOFT_CLIP) {
                         block.setSoftClipped(true);
                     }
-                    if (readRepresentativeCounts != null) {
-                        block.setCounts(blockCounts);
-                    }
                     alignmentBlocks[blockIdx++] = block;
 
                     fromIdx += op.nBases;
@@ -466,48 +376,22 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
                         gapTypes[gapIdx++] = ZERO_GAP;
                     }
 
-                } else if (op.operator == DELETION || op.operator == SKIPPED_REGION) {
+                } else if (op.operator == DELETION || op.operator == SKIPPED_REGION ) {
                     blockStart += op.nBases;
                     gapTypes[gapIdx++] = op.operator;
                 } else if (op.operator == INSERTION) {
-                    AlignmentBlock block = null;
-
                     // This gap is between blocks split by insertion.   It is a zero
                     // length gap but must be accounted for.
                     gapTypes[gapIdx++] = ZERO_GAP;
+                    AlignmentBlock block = buildAlignmentBlock(fBlockBuilder, readBases, readBaseQualities,
+                            readRepresentativeCounts, getChr(), blockStart, fromIdx, op.nBases, false);
 
-                    byte[] blockBases = new byte[op.nBases];
-                    byte[] blockQualities = new byte[op.nBases];
-                    short[] blockCounts = new short[op.nBases];
-
-                    if (readBases == null || readBases.length == 0) {
-                        Arrays.fill(blockBases, (byte) '=');
-                    } else {
-                        System.arraycopy(readBases, fromIdx, blockBases, 0, op.nBases);
-                    }
-
-                    if (readBaseQualities == null || readBaseQualities.length == 0) {
-                        Arrays.fill(blockQualities, (byte) 126);
-                    } else {
-                        System.arraycopy(readBaseQualities, fromIdx, blockQualities, 0, op.nBases);
-                    }
-
-                    if (readRepresentativeCounts != null) {
-                        System.arraycopy(readRepresentativeCounts, fromIdx, blockCounts, 0, op.nBases);
-                    }
-                    if (null != fBlockBuilder) {
-                        block = AlignmentBlock.getInstance(blockStart, blockBases, blockQualities,
-                                fBlockBuilder.getFlowSignalContext(readBases, fromIdx, op.nBases), this);
-                    } else {
-                        block = AlignmentBlock.getInstance(blockStart, blockBases, blockQualities, this);
-                    }
-                    if (readRepresentativeCounts != null) {
-                        block.setCounts(blockCounts);
-                    }
                     insertions[insertionIdx++] = block;
-
                     fromIdx += op.nBases;
-
+                } else if (op.operator == PADDING){
+                    //Padding represents a deletion against the padded reference
+                    //But we don't have the padded reference
+                    gapTypes[gapIdx++] = ZERO_GAP;
                 }
             } catch (Exception e) {
                 log.error("Error processing CIGAR string", e);
@@ -522,8 +406,55 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
                 end += last.nBases;
             }
         }
+    }
 
+    private static AlignmentBlock buildAlignmentBlock(FlowSignalContextBuilder fBlockBuilder, byte[] readBases,
+                                               byte[] readBaseQualities,
+                                               short[] readRepresentativeCounts, String chr, int blockStart,
+                                               int fromIdx, int nBases, boolean checkNBasesAvailable){
 
+        byte[] blockBases = new byte[nBases];
+        byte[] blockQualities = new byte[nBases];
+        short[] blockCounts = new short[nBases];
+
+        // TODO -- represent missing sequence ("*") explicitly for efficiency.
+        int nBasesAvailable = nBases;
+        if(checkNBasesAvailable){
+            nBasesAvailable = readBases.length - fromIdx;
+        }
+        if (readBases == null || readBases.length == 0) {
+            Arrays.fill(blockBases, (byte) '=');
+        } else if (nBasesAvailable < nBases) {
+            Arrays.fill(blockBases, (byte) '?');
+        } else {
+            System.arraycopy(readBases, fromIdx, blockBases, 0, nBases);
+        }
+
+        nBasesAvailable = nBases;
+        if(checkNBasesAvailable){
+            nBasesAvailable = readBaseQualities.length - fromIdx;
+        }
+        if (readBaseQualities == null || readBaseQualities.length == 0 || nBasesAvailable < nBases) {
+            Arrays.fill(blockQualities, (byte) 126);
+        } else {
+            System.arraycopy(readBaseQualities, fromIdx, blockQualities, 0, nBases);
+        }
+
+        if (readRepresentativeCounts != null) {
+            System.arraycopy(readRepresentativeCounts, fromIdx, blockCounts, 0, nBases);
+        }
+
+        AlignmentBlock block;
+        if (fBlockBuilder != null) {
+            block = AlignmentBlock.getInstance(chr, blockStart, blockBases, blockQualities,
+                    fBlockBuilder.getFlowSignalContext(readBases, fromIdx, nBases));
+        } else {
+            block = AlignmentBlock.getInstance(chr, blockStart, blockBases, blockQualities);
+        }
+        if (readRepresentativeCounts != null) {
+            block.setCounts(blockCounts);
+        }
+        return block;
     }
 
     private boolean operatorIsMatch(boolean showSoftClipped, char operator) {
@@ -531,41 +462,37 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
                 || (showSoftClipped && operator == SOFT_CLIP);
     }
 
-    public boolean isFirstInPair() {
-        return firstInPair;
-    }
-
     public boolean isNegativeStrand() {
-        return readNegativeStrandFlag;
+        return record.getReadNegativeStrandFlag();
     }
 
     public boolean isDuplicate() {
-        return duplicateReadFlag;
+        return this.record.getDuplicateReadFlag();
     }
 
     public boolean isMapped() {
-        return !readUnmappedFlag;
+        return !this.record.getReadUnmappedFlag();
     }
 
     @Override
     public int getReadLength() {
-        return this.readLength;
+        return this.record.getReadLength();
     }
 
     public boolean isPaired() {
-        return readPairedFlag;
+        return this.record.getReadPairedFlag();
     }
 
     public boolean isProperPair() {
-        return properPairFlag;
+        return isPaired() && this.record.getProperPairFlag();
     }
 
     public boolean isFirstOfPair() {
-        return this.firstRead;
+        return isPaired() && this.record.getFirstOfPairFlag();
     }
 
     public boolean isSecondOfPair() {
-        return this.secondRead;
+        return isPaired() && this.record.getSecondOfPairFlag();
     }
 
     /**
@@ -576,26 +503,30 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
     }
 
     public String getCigarString() {
-        return cigarString;
-    }
-
-    @ForTesting
-    String getReadSequenceField() {
-        return readSequence;
+        return this.record.getCigarString();
     }
 
     public String getReadSequence() {
-        String readSequence = this.readSequence != null ? this.readSequence : softReadSequence.get();
-        if (readSequence == null) {
-            readSequence = getRecord().getReadString();
-            this.softReadSequence = new SoftReference<String>(readSequence);
+        return this.record.getReadString();
+    }
+
+    /**
+     * Use blocks to recreate read sequence.
+     * As of this comment writing, we don't keep a block
+     * for hard-clipped bases, so this won't match what's in the file
+     * @return
+     */
+    String buildReadSequenceFromBlocks(){
+        String readSeq = "";
+        for(AlignmentBlock block: getAlignmentBlocks()){
+            readSeq += new String(block.getBases());
         }
-        return readSequence;
+        return readSeq;
     }
 
     @Override
     public boolean isPrimary() {
-        return !getRecord().getNotPrimaryAlignmentFlag();
+        return !this.record.getNotPrimaryAlignmentFlag();
     }
 
     /**
@@ -633,36 +564,11 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
         return library;
     }
 
-    private SAMFileSource getFileSource() {
-        return fileSource;
-    }
-
     /**
-     * Retrieves the SAMRecord corresponding to this alignment.
-     * May be loaded from the file if not in memory
-     *
      * @return The SAMRecord which created this SamAlignment
      */
     public SAMRecord getRecord() {
-        SAMRecord record = this.record != null ? this.record : this.softRecord.get();
-        if (record == null) {
-            SAMFileSource source = this.getFileSource();
-            if(source == null){
-                throw new IllegalStateException("SAMRecord is null but we don't have a file pointer to reload it");
-            }
-            SAMFileSpan span = source.getFilePointer();
-            SAMRecordIterator iter = source.getReader().iterator(span);
-
-            //In theory there should only be one
-            record = iter.next();
-
-            if (iter.hasNext()) {
-                log.error("Found multiple records during query of file span:" + span);
-            }
-            iter.close();
-            this.softRecord = new WeakReference<SAMRecord>(record);
-        }
-        return record;
+        return this.record;
     }
 
     @Override
@@ -776,14 +682,6 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
     }
 
     @Override
-    public String getMateSequence() {
-        return mateSequence;
-    }
-
-    public void setMateSequence(String mateSequence) {
-        this.mateSequence = mateSequence;
-    }
-
     public String getPairOrientation() {
         return pairOrientation;
     }
@@ -791,18 +689,10 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
     @Override
     public void finish() {
         super.finish();
-        SAMFileSource source = this.getFileSource();
-        if (DEFAULT_LAZY_LOAD && source != null) {
-            //Check that we can reload the record before getting rid of it.
-            //SAMTextReader doesn't support this, for instance
-            SAMFileSpan span = source.getFilePointer();
-            try{
-                SAMRecordIterator iter = source.getReader().iterator(span);
-                this.record = null;
-                //this.readSequence = null;
-            }catch(Exception e){
-                this.fileSource = null;
-            }
+
+        Genome genome = GenomeManager.getInstance().getCurrentGenome();
+        for(AlignmentBlock block: alignmentBlocks){
+            block.reduce(genome);
         }
     }
 
@@ -889,7 +779,7 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
 
         // get the # of bases that the first base in the read overlaps with the last base(s) in the key
         SAMRecord record = getRecord();
-        if (this.readNegativeStrandFlag) {
+        if (this.isNegativeStrand()) {
             firstBase = (char) NT2COMP[record.getReadBases()[record.getReadLength() - 1]];
         } else {
             firstBase = (char) record.getReadBases()[0];
