@@ -52,7 +52,7 @@ public class SessionWriter {
     static Logger log = Logger.getLogger(SessionWriter.class);
 
     Session session;
-    private static int CURRENT_VERSION = 5;
+    private static int CURRENT_VERSION = 6;
 
     private static final String TRACK_TAG = SessionElement.TRACK.getText();
 
@@ -107,17 +107,15 @@ public class SessionWriter {
 
             globalElement.setAttribute(SessionAttribute.VERSION.getText(), String.valueOf(CURRENT_VERSION));
 
-            String genome = GenomeManager.getInstance().getGenomeId();
-            if (genome != null) {
-                globalElement.setAttribute(SessionAttribute.GENOME.getText(), genome);
+            String genomeId = GenomeManager.getInstance().getGenomeId();
+            if (genomeId != null) {
+                globalElement.setAttribute(SessionAttribute.GENOME.getText(), genomeId);
             }
 
-            //if (!FrameManager.isGeneListMode()) {
             String locus = session.getLocusString();
             if (locus != null && !FrameManager.isGeneListMode()) {
                 globalElement.setAttribute(SessionAttribute.LOCUS.getText(), locus);
             }
-            //}
 
             String groupBy = IGV.getInstance().getGroupByAttribute();
             if (groupBy != null) {
@@ -128,6 +126,7 @@ public class SessionWriter {
                 globalElement.setAttribute("removeEmptyTracks", "true");
             }
 
+            globalElement.setAttribute(SessionAttribute.HAS_GENE_TRACK.getText(), "" + IGV.getInstance().hasGeneTrack());
 
             // Resource Files
             writeResources(outputFile, globalElement, document);
@@ -303,14 +302,14 @@ public class SessionWriter {
                     if (resourceLocator.getName() != null) {
                         dataFileElement.setAttribute(SessionAttribute.NAME.getText(), resourceLocator.getName());
                     }
-                    if (resourceLocator.getServerURL() != null) {
-                        dataFileElement.setAttribute(SessionAttribute.SERVER_URL.getText(), resourceLocator.getServerURL());
+                    if (resourceLocator.getDBUrl() != null) {
+                        dataFileElement.setAttribute(SessionAttribute.SERVER_URL.getText(), resourceLocator.getDBUrl());
                     }
-                    if (resourceLocator.getInfolink() != null) {
-                        dataFileElement.setAttribute(SessionAttribute.HYPERLINK.getText(), resourceLocator.getInfolink());
+                    if (resourceLocator.getTrackInforURL() != null) {
+                        dataFileElement.setAttribute(SessionAttribute.HYPERLINK.getText(), resourceLocator.getTrackInforURL());
                     }
-                    if (resourceLocator.getUrl() != null) {
-                        dataFileElement.setAttribute(SessionAttribute.FEATURE_URL.getText(), resourceLocator.getUrl());
+                    if (resourceLocator.getFeatureInfoURL() != null) {
+                        dataFileElement.setAttribute(SessionAttribute.FEATURE_URL.getText(), resourceLocator.getFeatureInfoURL());
                     }
                     if (resourceLocator.getDescription() != null) {
                         dataFileElement.setAttribute(SessionAttribute.DESCRIPTION.getText(), resourceLocator.getDescription());
