@@ -11,7 +11,6 @@
 
 package org.broad.igv.track;
 
-import net.sf.samtools.seekablestream.SeekableStream;
 import org.apache.log4j.Logger;
 import org.broad.igv.PreferenceManager;
 import org.broad.igv.bbfile.BBFileReader;
@@ -58,12 +57,11 @@ import org.broad.igv.tdf.TDFDataSource;
 import org.broad.igv.tdf.TDFReader;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.util.ConfirmDialog;
+import org.broad.igv.ui.util.IndexCreatorDialog;
 import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.util.HttpUtils;
 import org.broad.igv.util.ParsingUtils;
 import org.broad.igv.util.ResourceLocator;
-import org.broad.igv.util.stream.IGVSeekableBufferedStream;
-import org.broad.igv.util.stream.IGVSeekableStreamFactory;
 import org.broad.igv.variant.VariantTrack;
 import org.broad.igv.variant.util.PedigreeUtils;
 import org.broad.tribble.AbstractFeatureReader;
@@ -124,8 +122,8 @@ public class TrackLoader {
             //This list will hold all new tracks created for this locator
             List<Track> newTracks = new ArrayList<Track>();
 
-            String serverURL = locator.getServerURL();
-            if (serverURL != null && serverURL.startsWith("jdbc:")) {
+            String dbUrl = locator.getDBUrl();
+            if (dbUrl != null) {
                 this.loadFromDatabase(locator, newTracks, genome);
             } else if (typeString.endsWith(".dbxml")) {
                 loadFromDBProfile(locator, newTracks);
@@ -135,13 +133,26 @@ public class TrackLoader {
                 loadDASResource(locator, newTracks);
             } else if (MutationTrackLoader.isMutationAnnotationFile(locator)) {
                 this.loadMutFile(locator, newTracks, genome); // Must be tried before generic "loadIndexed" below
+            } else if ((typeString.endsWith(".vcf3") || typeString.endsWith(".vcf4") || typeString.endsWith(".vcf")) && !HttpUtils.isRemoteURL(locator.getPath())) {
+                //Prompt user to see if they want to create an index file for VCFs
+                if(!isIndexed(path, genome)){
+                    File baseFile = new File(locator.getPath());
+                    File newIdxFile = new File(locator.getPath() + ".idx");
+                    IndexCreatorDialog dialog = IndexCreatorDialog.createShowDialog(IGV.getMainFrame(), baseFile, newIdxFile);
+                    Object index = dialog.getIndex();
+                    //If user hits cancel or if there's a problem indexing we do nothing
+                    if(index == null) {
+                        log.warn("No index created, loading cancelled");
+                        return newTracks;
+                    }
+                }
+                loadIndexed(locator, newTracks, genome);
+            } else if(VCFrequiresIndex(path) && !isIndexed(path, genome)){
+                throw new DataLoadException("Could not access required index file", path);
             } else if (isIndexed(path, genome)) {
                 loadIndexed(locator, newTracks, genome);
             } else if (typeString.endsWith(".vcf.list")) {
                 loadVCFListFile(locator, newTracks, genome);
-            } else if (typeString.endsWith(".vcf") || typeString.endsWith(".vcf4")) {
-                // VCF files must be indexed.
-                throw new IndexNotFoundException(path);
             } else if (typeString.endsWith(".trio")) {
                 loadTrioData(locator);
             } else if (typeString.endsWith("varlist")) {
@@ -204,12 +215,11 @@ public class TrackLoader {
                 loadWigFile(locator, newTracks, genome);
             } else if (typeString.endsWith(".maf")) {
                 loadMultipleAlignmentTrack(locator, newTracks, genome);
-
             } else if (typeString.endsWith(".maf.dict")) {
                 loadMultipleAlignmentTrack(locator, newTracks, genome);
-            } else if (path.toLowerCase().contains(".peak.bin")) {
+            } else if (typeString.contains(".peak.bin")) {
                 loadPeakTrack(locator, newTracks, genome);
-            } else if ("mage-tab".equals(locator.getType()) || ExpressionFileParser.parsableMAGE_TAB(locator)) {
+            } else if ("mage-tab".equals(typeString) || ExpressionFileParser.parsableMAGE_TAB(locator)) {
                 locator.setDescription("MAGE_TAB");
                 loadGctFile(locator, newTracks, genome);
             } else if (GWASParser.isGWASFile(typeString)) {
@@ -236,8 +246,8 @@ public class TrackLoader {
 
             for (Track track : newTracks) {
 
-                if (locator.getUrl() != null) {
-                    track.setUrl(locator.getUrl());
+                if (locator.getFeatureInfoURL() != null) {
+                    track.setUrl(locator.getFeatureInfoURL());
                 }
                 if (tp != null) {
                     track.setProperties(tp);
@@ -259,6 +269,17 @@ public class TrackLoader {
 
     }
 
+    private boolean VCFrequiresIndex(String path) {
+        String fn = stripGZ(path);
+        String[] exts = new String[]{".vcf3", ".vcf4", ".vcf"};
+        for(String ext: exts){
+            if(fn.endsWith(ext)){
+                return true;
+            }
+        }
+        return false;
+    }
+
     private void loadGMT(ResourceLocator locator) throws IOException {
         List<GeneList> lists = GeneListManager.getInstance().importGMTFile(locator.getPath());
         if (lists.size() == 1) {
@@ -387,7 +408,7 @@ public class TrackLoader {
      */
     private void loadGFFfile(ResourceLocator locator, List<Track> newTracks, Genome genome) throws IOException {
 
-        GFFParser featureParser = new GFFParser(locator.getPath());
+        GFFParser featureParser = new GFFParser();
         List<FeatureTrack> tracks = featureParser.loadTracks(locator, genome);
         newTracks.addAll(tracks);
     }
@@ -890,7 +911,7 @@ public class TrackLoader {
             String dsName = locator.getTrackName();
 
             // If the user tried to load the index,  look for the file (this is a common mistake)
-            if (locator.getPath().endsWith(".sai") || locator.getPath().endsWith(".bai")) {
+            if (locator.getTypeString().endsWith(".sai") || locator.getTypeString().endsWith(".bai")) {
                 MessageUtils.showMessage("<html><b>ERROR:</b> Loading SAM/BAM index files are not supported:  " + locator.getPath() +
                         "<br>Load the SAM or BAM file directly. ");
                 return;
@@ -1074,8 +1095,8 @@ public class TrackLoader {
 
         //For backwards/forwards compatibility
         //We used to put path in the serverURL field
-        ResourceLocator dbLocator = new ResourceLocator(locator.getServerURL());
-        if (".seg".equals(locator.getType())) {
+        ResourceLocator dbLocator = new ResourceLocator(locator.getDBUrl());
+        if (".seg".equals(locator.getTypeString())) {
             //TODO Don't hardcode table name, this might note even be right for our target case
             SegmentedAsciiDataSet ds = (new SegmentedSQLReader(dbLocator, "CNV", genome)).load();
             loadSegTrack(locator, newTracks, genome, ds);
@@ -1223,14 +1244,24 @@ public class TrackLoader {
      * @return
      */
     private static boolean isIndexable(String path, Genome genome) {
+        String fn = stripGZ(path);
+        // The vcf extension is for performance, it doesn't matter which codec is returned all vcf files
+        // are indexable.
+        return fn.endsWith(".vcf") || fn.endsWith(".bcf") || CodecFactory.getCodec(path, genome) != null;
+    }
+
+    /**
+     * Strip .gz extension if on path
+     * @param path
+     * @return
+     */
+    private static String stripGZ(String path){
         String fn = path.toLowerCase();
         if (fn.endsWith(".gz")) {
             int l = fn.length() - 3;
             fn = fn.substring(0, l);
         }
-        // The vcf extension is for performance, it doesn't matter which codec is returned all vcf files
-        // are indexable.
-        return fn.endsWith(".vcf") || fn.endsWith(".bcf") || CodecFactory.getCodec(path, genome) != null;
+        return fn;
     }
 
     public static TrackProperties getTrackProperties(Object header) {
