@@ -279,6 +279,19 @@ public class IGV {
         glassPane = rootPane.getGlassPane();
         glassPane.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
         glassPane.addMouseListener(new MouseAdapter() {
+            @Override
+            public void mouseClicked(MouseEvent e) {
+                super.mouseClicked(e);
+                if (!Globals.isProduction()) {
+                    Component cButton = contentPane.getStatusBar().getCancelButton();
+                    int tX = -(contentPane.getStatusBar().getX() + cButton.getX());
+                    int tY = -(contentPane.getY() + contentPane.getStatusBar().getY());
+                    e.translatePoint(tX, tY);
+                    if (cButton.contains(e.getPoint())) {
+                        contentPane.getStatusBar().getCancelButton().doClick();
+                    }
+                }
+            }
         });
         dNdGlassPane = new GhostGlassPane();
 
@@ -609,6 +622,16 @@ public class IGV {
     }
 
     public void loadGenome(String path, ProgressMonitor monitor) throws IOException {
+        loadGenome(path, monitor, true);
+    }
+
+    /**
+     * @param path
+     * @param monitor
+     * @param addGenomeTrack Whether to display the gene track as well
+     * @throws IOException
+     */
+    public void loadGenome(String path, ProgressMonitor monitor, boolean addGenomeTrack) throws IOException {
 
         File file = new File(path);
         if (file.exists()) {
@@ -618,7 +641,7 @@ public class IGV {
 
         resetSession(null);
 
-        Genome genome = getGenomeManager().loadGenome(path, monitor);
+        Genome genome = getGenomeManager().loadGenome(path, monitor, addGenomeTrack);
         //If genome loading cancelled
         if (genome == null) return;
 
@@ -2050,7 +2073,7 @@ public class IGV {
             }
         }
 
-        for(Track t : tracksToRemove) {
+        for (Track t : tracksToRemove) {
             t.dispose();
         }
     }
@@ -2075,6 +2098,14 @@ public class IGV {
 
     }
 
+    public boolean hasGeneTrack() {
+        FeatureTrack geneTrack = GenomeManager.getInstance().getCurrentGenome().getGeneTrack();
+        if (geneTrack == null) return false;
+        for (FeatureTrack ft : getFeatureTracks()) {
+            if (geneTrack == ft) return true;
+        }
+        return false;
+    }
 
     /////////////////////////////////////////////////////////////////////////////////////////
     // Sorting
@@ -2342,7 +2373,7 @@ public class IGV {
             if (igvArgs.getSessionFile() != null || igvArgs.getDataFileString() != null) {
 
                 if (log.isDebugEnabled()) {
-                    log.debug("Loadding session data");
+                    log.debug("Loading session data");
                 }
 
                 final IndefiniteProgressMonitor indefMonitor = new IndefiniteProgressMonitor();
@@ -2383,15 +2414,16 @@ public class IGV {
                     List<ResourceLocator> locators = new ArrayList();
                     int idx = 0;
                     for (String p : tokens) {
+
+                        // Decode local file paths
+                        if (HttpUtils.isURL(p) && !FileUtils.isRemote(p)) {
+                            p = StringUtils.decodeURL(p);
+                        }
+
                         ResourceLocator rl = new ResourceLocator(p);
+
                         if (names != null && idx < names.length) {
                             String name = names[idx];
-
-                            // Decode local file paths
-                            if (!FileUtils.isRemote(name)) {
-                                name = StringUtils.decodeURL(name);
-                            }
-
                             rl.setName(name);
                         }
                         rl.setIndexPath(indexFile);
