@@ -101,20 +101,19 @@ public class HttpUtils {
 
 
     /**
-     * @deprecated HttpUtils.openConnection does URL encoding itself
-     *
-     * Join the {@code elements} with the character {@code joiner},
-     * URLencoding the {@code elements} along the way. {@code joiner}
-     * is NOT URLEncoded
-     * Example:
-     * String[] parm_list = new String[]{"app les", "oranges", "bananas"};
-     * String formatted = buildURLString(Arrays.asList(parm_list), "+");
-     * <p/>
-     * formatted will be "app%20les+oranges+bananas"
-     *
      * @param elements
      * @param joiner
      * @return
+     * @deprecated HttpUtils.openConnection does URL encoding itself
+     *             <p/>
+     *             Join the {@code elements} with the character {@code joiner},
+     *             URLencoding the {@code elements} along the way. {@code joiner}
+     *             is NOT URLEncoded
+     *             Example:
+     *             String[] parm_list = new String[]{"app les", "oranges", "bananas"};
+     *             String formatted = buildURLString(Arrays.asList(parm_list), "+");
+     *             <p/>
+     *             formatted will be "app%20les+oranges+bananas"
      */
     @Deprecated
     public static String buildURLString(Iterable<String> elements, String joiner) {
@@ -322,6 +321,28 @@ public class HttpUtils {
         proxySettings = new ProxySettings(useProxy, user, pw, auth, proxyHost, proxyPort, type);
     }
 
+    /**
+     * Get the system defined proxy defined for the URI, or null if
+     * not available. May also return a {@code Proxy} object which
+     * represents a direct connection
+     *
+     * @param uri
+     * @return
+     */
+    private Proxy getSystemProxy(String uri) {
+        try {
+            ProxySelector selector = ProxySelector.getDefault();
+            List<Proxy> proxyList = selector.select(new URI(uri));
+            return proxyList.get(0);
+        } catch (URISyntaxException e) {
+            log.error(e.getMessage(), e);
+            return null;
+        } catch (NullPointerException e) {
+            return null;
+        }
+
+    }
+
     public boolean downloadFile(String url, File outputFile) throws IOException {
 
         log.info("Downloading " + url + " to " + outputFile.getAbsolutePath());
@@ -517,12 +538,9 @@ public class HttpUtils {
     private HttpURLConnection openConnection(
             URL url, Map<String, String> requestProperties, String method, int redirectCount) throws IOException {
 
-        boolean useProxy = proxySettings != null && proxySettings.useProxy && proxySettings.proxyHost != null &&
-                proxySettings.proxyPort > 0;
-
         //Encode query string portions
         url = StringUtils.encodeURLQueryString(url);
-        if(log.isTraceEnabled()){
+        if (log.isTraceEnabled()) {
             log.trace(url);
         }
 
@@ -533,12 +551,19 @@ public class HttpUtils {
             url = new URL(newPath);
         }
 
+        Proxy sysProxy = getSystemProxy(url.toExternalForm());
+        boolean igvProxySettingsExist = proxySettings != null && proxySettings.useProxy && proxySettings.proxyHost != null && proxySettings.proxyPort > 0;
+        boolean useProxy = sysProxy != null || igvProxySettingsExist;
+
         HttpURLConnection conn;
         if (useProxy) {
-            Proxy proxy = new Proxy(proxySettings.type, new InetSocketAddress(proxySettings.proxyHost, proxySettings.proxyPort));
+            Proxy proxy = sysProxy;
+            if (igvProxySettingsExist) {
+                proxy = new Proxy(proxySettings.type, new InetSocketAddress(proxySettings.proxyHost, proxySettings.proxyPort));
+            }
             conn = (HttpURLConnection) url.openConnection(proxy);
 
-            if (proxySettings.auth && proxySettings.user != null && proxySettings.pw != null) {
+            if (igvProxySettingsExist && proxySettings.auth && proxySettings.user != null && proxySettings.pw != null) {
                 byte[] bytes = (proxySettings.user + ":" + proxySettings.pw).getBytes();
 
                 String encodedUserPwd = String.valueOf(Base64Coder.encode(bytes));
@@ -612,8 +637,8 @@ public class HttpUtils {
                     message = conn.getResponseMessage();
                 }
                 String details = readErrorStream(conn);
-                log.error("error stream: " + details);
-                log.error(message);
+                log.error("URL: " + url.toExternalForm() + ". error stream: " + details);
+                log.error("Code: " + code + ". " + message);
                 HttpResponseException exc = new HttpResponseException(code);
                 throw exc;
             }
@@ -707,9 +732,8 @@ public class HttpUtils {
                 // We could not reach the test server, so we can't know if this client can do byte-range tests or
                 // not.  Take the "optimistic" view.
                 return true;
-            }
-            finally {
-                if(str != null) try {
+            } finally {
+                if (str != null) try {
                     str.close();
                 } catch (IOException e) {
                     log.error("Error closing stream (" + url.toExternalForm() + ")", e);
@@ -772,6 +796,18 @@ public class HttpUtils {
         return f.startsWith("http:") || f.startsWith("ftp:") || f.startsWith("https:") || URLmatcher.matcher(f).matches();
     }
 
+    public static Map<String, String> parseQueryString(String query) {
+        String[] params = query.split("&");
+        Map<String, String> map = new HashMap<String, String>();
+        for (String param : params) {
+            String name = param.split("=")[0];
+            String value = param.split("=")[1];
+            map.put(name, value);
+        }
+        return map;
+    }
+
+
     public static class ProxySettings {
         boolean auth = false;
         String user;
